==> aws-android-sdk-cognito-2.2.18-sources.jar: com/amazonaws/services/cognitosync/model/Operation.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cognitosync.model;

/**
 * Operation
 */
public enum Operation {
    
    Replace("replace"),
    Remove("remove");

    private String value;

    private Operation(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *            real value
     * @return Operation corresponding to the value
     */
    public static Operation fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        
        } else if ("replace".equals(value)) {
            return Operation.Replace;
        } else if ("remove".equals(value)) {
            return Operation.Remove;
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}

==> aws-android-sdk-cognito-2.3.3-sources.jar: com/amazonaws/services/cognitosync/model/Operation.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitosync.model;

import java.util.HashMap;
import java.util.Map;

/**
 * Operation
 */
public enum Operation {

    Replace("replace"),
    Remove("remove");

    private String value;

    private Operation(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return value;
    }

    private static final Map<String, Operation> enumMap;
    static {
        enumMap = new HashMap<String, Operation>();
        enumMap.put("replace", Replace);
        enumMap.put("remove", Remove);
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value real value
     * @return Operation corresponding to the value
     */
    public static Operation fromValue(String value) {
        if (value == null || value.isEmpty()) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        } else if (enumMap.containsKey(value)) {
            return enumMap.get(value);
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}
